@@ -23,12 +23,15 @@ class TaskCategory:
 class TaskType(str, Enum):
     text_classification = "text-classification"
     named_entity_recognition = "named-entity-recognition"
-    extractive_qa = "extractive-qa"
+    extractive_qa_squad = "extractive-qa-squad"
     summarization = "summarization"
     text_pair_classification = "text-pair-classification"
     hellaswag = "hellaswag"
     aspect_based_sentiment_classification = "aspect-based-sentiment-classification"
 
+    kg_link_tail_prediction = "kg-link-tail-prediction"
+
+
     @staticmethod
     def list():
         return list(map(lambda c: c.value, TaskType))
@@ -88,8 +91,8 @@ _task_categories: List[TaskCategory] = [
                  ),
     TaskCategory("question-answering", "question answering tasks",
                  [
-                     Task(name = TaskType.extractive_qa,
-                          description = "A task of extracting an answer from a text given a question",
+                     Task(name = TaskType.extractive_qa_squad,
+                          description = "A task of extracting an answer from a text given a question on the SQuAD dataset",
                           supported = True,
                           supported_metrics = ["f1_score_qa", "exact_match_qa"],
                           supported_formats=["json"],
@@ -115,6 +118,15 @@ _task_categories: List[TaskCategory] = [
                           supported_formats=["tsv"],
                           ),
                  ]),
+    TaskCategory("kg-link-tail-prediction", "predicting the tail entity of missing links in knowledge graphs",
+                 [
+                     Task(name = TaskType.kg_link_tail_prediction, 
+                          description = "predicting the tail entity of missing links in knowledge graphs", 
+                          supported = True, 
+                          supported_metrics = ["Hits"],
+                          supported_formats = ["json"],
+                          ),
+                 ]),
 ]
 
 
